/***********************************************************************/
/* DRDLGINS                                                            */
/*                                                                     */
/* Purpose: Uses XCOPY to install all files from a sub directory       */
/*          into a user specified destination directory.               */
/*                                                                     */
/* Parameters: BootDrive: Drive letter where system boots              */
/*             Install Drive: Drive letter and path of CDROM           */
/*             Program Name: Name of the program to install.           */
/*             Source:       Directory where program is located.       */
/*             Destination:  Default installation directory.           */
/*             Options: any options                                    */
/***********************************************************************/
/*                (C) Copyright IBM Corporation 1992                   */
/***********************************************************************/
parse upper arg Ctl.!BDr Ctl.!CDr Ctl.!ProgName Ctl.!Source Ctl.!Destination Ctl.!Options
trace 'o'
call on halt
if Ctl.!BDr = '?'
  then call Tell
Globals = 'Ctl.' 'RXCADD.'

call Initialize

if RxCaDD.OpType = 'REMOVE'
  then do
    call 'MessageBox' Ctl.!ProgName, 'Remove is not supported.  Add the application',
         'again to recreate the program object.'
    call 'CaDDExit'
    exit 0
  end  /* Do */

if substr(Ctl.!BDr,2, 1) <> ':' | substr(Ctl.!CDr,2,1) <> ':'
  then call MyExit 302
if \Ctl.!Quiet
  then call PromptDestination Ctl.!Destination
Resp = MakeDestination(Ctl.!Destination)
Ctl.!CurDir = directory()
temp = directory(Ctl.!Destination)
if temp <> Ctl.!Destination
  then call MyExit 303
call directory(Ctl.!CurDir)
call CopyFiles

call CreateFolders

call MyExit 0
exit

Initialize: procedure expose (Globals)
CurDir = directory()
call directory Ctl.!CDr'INSTALL'
call Rxfuncadd 'CADDINIT', 'RXCADD', 'CADDINIT'
signal on syntax
ver = 'CAddInit'()
signal off syntax
if abbrev(ver, 'ERROR:')
  then call syntax
Ctl.!Valid = 0
Ctl.!Quiet = (wordpos('/N', Ctl.!Options) <> 0)
Ctl.!NoComp = (wordpos('/C', Ctl.!Options) <> 0)

return 0

CopyFiles: procedure expose (Globals)
/* '@ECHO OFF' */
if \Ctl.!Quiet
  then do
    say 'Ŀ'
    say ''center('Copying files for 'Ctl.!Progname' Please wait...',76)''
    say ''
  end /* Do */
do while queued() <> 0
  pull .
end /* do */
'XCOPY 'Ctl.!Source Ctl.!Destination'\*.* /s /e >nul 2>nul'
Resp = rc
if Resp \= 0
  then call MyExit 301
if \Ctl.!Quiet
  then do
    say 'Ŀ'
    say ''center('All files copied successfully.', 76)''
    say ''
  end /* Do */
return 0

PromptDestination: procedure expose (Globals)
parse arg path
'@ECHO OFF'
do until answer = 'Y'
  'cls'
  say
  say 'Ŀ'
  say '                       The Developer Connection                             '
  say '            'right(Ctl.!ProgName,20)' Installation                               '
  say '                  (C) Copyright IBM Corporation 1993                        '
  say ''
  say
  say 'The installation path for 'Ctl.!ProgName' is 'path
  say
  say 'To ONLY change the drive, enter d: (where d is the new drive letter)'
  say 'To ONLY change the path, enter \path (where path is the new path)'
  say
  say 'Enter a new destination for 'Ctl.!ProgName', hit enter for default path, or Q to QUIT:'

  tmppath = translate(linein(STDIN))
  if tmppath = 'Q'
    then call MyExit 300
  if tmppath \= ''
    then do
      if (length(tmppath)=2) & (substr(tmppath,2,1)=':') then
        tmppath = tmppath||substr(path,3)
      else if substr(tmppath,1,1)='\' then
        tmppath=substr(path,1,2)||tmppath
      say
      say tmppath' is the new path.  Is this correct (Yes/No)?'
      answer = translate(linein(STDIN))
      l1 = substr(answer, 1, 1)
      do while l1 \= 'Y' & l1 \= 'N'
        say beep(450,150)'Please enter Y(es) or N(o)'
        answer = translate(linein(STDIN))
        l1 = substr(answer, 1, 1)
      end /* do */
      parse value reverse(RxCadd.ProgInfo.4) with fname'\'.
      RxCadd.ProgInfo.4='EXE='tmppath'\'reverse(fname)
      RxCadd.ProgInfo.6='WORKDIR='tmppath
      if right(tmppath,1) = '\'
        then tmppath = strip(tmppath, 'T', '\')
      Ctl.!Destination = tmppath
    end
    else return path
end /* Do */
return

MakeDestination: procedure expose (Globals)
parse arg subdir
dirty = 0
'@ECHO OFF'
do forever
  'mkdir 'subdir' >nul 2>nul'
  if rc = 0 | dirty = 1 | length(subdir) <= 2
    then return rc
    else do
      call MakeDestination(substr(subdir,1,(lastpos('\',subdir)-1)))
      Dirty = 1
    end  /* Do */
end /* do */
return rc

        /***********  CreateFolder  *******************/
CreateFolders: procedure expose (Globals)

/* Install DrDialog's Workplace Shell objects */
CALL RxFuncAdd "SysLoadFuncs", "RexxUtil", "SysLoadFuncs"
Call SysLoadFuncs
                /** makes destination directory the home directory **/
dir = Directory(Ctl.!Destination)
'@cd ' dir
/* Remove old associations, if any */
Call SysIni 'USER', 'PMWP_ASSOC_TYPE', 'DrDialog.RES', 'DELETE:'
Call SysIni 'USER', 'PMWP_ASSOC_TYPE', 'DrRexx.RES', 'DELETE:'

/* Changed flag to "UpdateIfExists" to keep the folder contents. */
msg = "create the DrDialog folder"
rc  = SysCreateObject( "WPFolder", "DrDialog", "<DEVCON_OS2_FOLDER>", "OBJECTID=<DRDIALOG>;", "U" )
If \rc Then Call FAILED

msg = "find DrRexx.EXE"
rc  = SysFileTree( "DRREXX.EXE", "FILE", "FO" )
IF rc \= 0 THEN Signal ABORT
msg = "create DrRexx program object"
rc  = SysCreateObject( "WPProgram", "DrRexx", "<DRDIALOG>", "PROGTYPE=PM;EXENAME="file.1";ASSOCTYPE=DrRexx.RES;STARTUPDIR="dir";", "R" )
If \rc Then Call FAILED

msg = "create REStoPgm program object"
rc  = SysCreateObject( "WPProgram", "REStoPgm", "<DRDIALOG>", "PROGTYPE=PM;EXENAME="file.1";STARTUPDIR="dir";PARAMETERS="dir"\REStoPgm %*", "R" )
If \rc Then Call FAILED

msg = "create REStoEXE program object"
rc  = SysCreateObject( "WPProgram", "REStoEXE", "<DRDIALOG>", "PROGTYPE=PM;EXENAME="file.1";STARTUPDIR="dir";PARAMETERS="dir"\REStoEXE %*", "R" )
If \rc Then Call FAILED

msg = "create REStoRXX program object"
rc  = SysCreateObject( "WPProgram", "REStoRXX", "<DRDIALOG>", "PROGTYPE=PM;EXENAME="file.1";STARTUPDIR="dir";PARAMETERS="dir"\REStoRXX %*", "R" )
If \rc Then Call FAILED

msg = "find DrDialog.EXE"
rc  = SysFileTree( "DRDIALOG.EXE", "FILE", "FO" )
IF rc \= 0 THEN Signal ABORT
msg = "create DrDialog program object"
rc  = SysCreateObject( "WPProgram", "DrDialog", "<DRDIALOG>", "PROGTYPE=PM;EXENAME="file.1";ASSOCTYPE=DrDialog.RES,DrRexx.RES;STARTUPDIR="dir";", "R" )
If \rc Then Call FAILED

msg  = "Find OS/2 system VIEW.EXE program"
view = SysSearchPath( "PATH", "VIEW.EXE" )
IF view = "" THEN Signal ABORT
msg = "find DrDialog on-line reference file"
rc  = SysFileTree( "DRDIALOG.INF", "FILE", "FO" )
IF rc \= 0 THEN Signal ABORT
msg = "create on-line reference object"
rc = SysCreateObject( "WPProgram", "DrDialog reference", "<DRDIALOG>", "PROGTYPE=PM;EXENAME="view";PARAMETERS="file.1";", "R"  )
If \rc Then Call FAILED

/* msg = "create shadow of 'SAMPLE' folder"    */
/* rc  = SysCreateObject( "WPShadow", "SAMPLE", "<DRDIALOG>", "SHADOWID="dir'\SAMPLE;', "R" ) */
/* If \rc Then Call FAILED */

msg = "create shadow of DrRexx.RES template object"
rc  = SysCreateObject( "WPShadow", "DrRexx.RES", "<DRDIALOG>", "SHADOWID="dir'\DRREXX.RES;', "R" )
If \rc Then Call FAILED
msg = "create shadow of DrDialog.RES template object"
rc  = SysCreateObject( "WPShadow", "DrDialog.RES", "<DRDIALOG>", "SHADOWID="dir'\DRDIALOG.RES;', "R" )
If \rc Then Call FAILED

/* Now make sure that the templates have the correct "Type" EA: */
/* Set the "TEMPLATE=" setup option */
Call SysSetObjectData dir'\DRDIALOG.RES', 'TEMPLATE=YES;'
Call SysSetObjectData dir'\DRREXX.RES', 'TEMPLATE=YES;'
Call SysPutEA 'DRREXX.RES', ".TYPE", 'DFFF00000100FDFF'x||D2C(Length('DrRexx.RES'))||'00'x||'DrRexx.RES'
Call SysPutEA 'DRDIALOG.RES', ".TYPE", 'DFFF00000100FDFF'x||D2C(Length('DrDialog.RES'))||'00'x||'DrDialog.RES'

SAY "DrDialog installation complete..."
SAY "You may now open the 'DrDialog' folder"
SAY "in The Developer Connection for OS/2 folder."
return

FAILED:
SAY "Failed trying to" msg
RETURN

ABORT:
SAY "Failed trying to" msg
return
        /*********** end of CreateFolders **********************/

MyExit: procedure expose (Globals)
parse arg Resp

select
  when Resp = 300 & \Ctl.!Quiet
    then do
      call 'MessageBox' Ctl.!ProgName, 'Installation ended by user.'
    end /* Do */
  when Resp = 301 & \Ctl.!Quiet
    then do
      call 'MessageBox' Ctl.!ProgName, 'Installation failed when copying files to 'Ctl.!Destination'.'
    end /* Do */
  when Resp = 302 & \Ctl.!Quiet
    then do
      call 'MessageBox' Ctl.!ProgName,'Could not find OS/2 2.0 Boot Drive or CD-ROM path.',
                        'Make sure that INSTALL was run from the drive letter of the CD-ROM.'
    end  /* Do */
  when Resp = 303 & \Ctl.!Quiet
    then do
      call beep 250, 150
      call 'MessageBox' Ctl.!ProgName, 'Could not create destination directory 'Ctl.!Destination
    end  /* Do */
  otherwise
    nop
end  /* select */
if \Ctl.!NoComp
  then do
    call 'CaddComplete' Resp
    call 'CaDDExit'
  end
exit Resp

Tell:

say
say 'DRDLGINS.CMD'
say
say 'Purpose: Generalized installation tool for PDT CD ROM.  This will handle DLL'
say '         placement and HELP files if they are present.  For OS/2 2.0 only.'
say
say 'Syntax:  DRDLGINS BDr CDr Title Source Dest Options'
say
say 'Parameters:  BDr:    Drive OS/2 is installed onto.'
say '             CDr:    CD ROM drive path.'
say '             Title:  Name of program being installed.'
say '             Source: Location of program files.'
say '             Dest:   Default installation path.'
say
say '             Options: /N   Quiet mode.'
exit 0

Syntax:

call beep 350, 150
say
say 'Ŀ'
say '  Dot not found in LIBPATH.  A dot will be automatically added to your  '
say '  CONFIG.SYS LIBPATH entry.  The DOT is necessary for the installation  '
say '  to find its DLL files in the current directory.                       '
say ''
'@echo off'
'call LIBADD . 'Ctl.!BDr'\CONFIG.SYS >nul 2>nul'
Resp = rc
if rc = 0
  then do
    call beep 350, 150
    say
    say 'Ŀ'
    say '                 REBOOT the system and try install again.               '
    say ''
  end
  else do
    call beep 350, 150
    say
    say 'Ŀ'
    say '   Unable to update CONFIG.SYS please do so manually then REBOOT.       '
    say ''
  end /* Do */
exit 200

halt:

call MyExit 2
return
